Index: trunk/src/org/openstreetmap/josm/gui/history/VersionInfoPanel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/history/VersionInfoPanel.java	(revision 11408)
+++ trunk/src/org/openstreetmap/josm/gui/history/VersionInfoPanel.java	(revision 11416)
@@ -202,7 +202,5 @@
         if (primitive != null) {
             Changeset cs = primitive.getChangeset();
-            if (cs != null) {
-                update(cs, model.isLatest(primitive), primitive.getTimestamp(), primitive.getVersion());
-            }
+            update(cs, model.isLatest(primitive), primitive.getTimestamp(), primitive.getVersion());
         }
     }
@@ -219,5 +217,5 @@
     /**
      * Updates the content of this panel based on the changeset information given by {@code cs}.
-     * @param cs the changeset information - must not be null
+     * @param cs the changeset information
      * @param isLatest whether this relates to a not yet commited changeset
      * @param timestamp the timestamp
@@ -227,5 +225,5 @@
         lblInfo.setText(getInfoText(timestamp, version, isLatest));
 
-        if (!isLatest) {
+        if (!isLatest && cs != null) {
             User user = cs.getUser();
             String url = Main.getBaseBrowseUrl() + "/changeset/" + cs.getId();
@@ -299,5 +297,7 @@
         @Override
         public void actionPerformed(ActionEvent e) {
-            ChangesetDialog.LaunchChangesetManager.displayChangesets(Collections.singleton(id));
+            if (id != null) {
+                ChangesetDialog.LaunchChangesetManager.displayChangesets(Collections.singleton(id));
+            }
             if (componentToSelect != null) {
                 ChangesetCacheManager.getInstance().setSelectedComponentInDetailPanel(componentToSelect);
Index: trunk/src/org/openstreetmap/josm/gui/widgets/UrlLabel.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/widgets/UrlLabel.java	(revision 11408)
+++ trunk/src/org/openstreetmap/josm/gui/widgets/UrlLabel.java	(revision 11416)
@@ -74,5 +74,5 @@
 
     protected final void refresh() {
-        if (url != null) {
+        if (url != null && !url.isEmpty()) {
             setText("<html><a href=\""+url+"\">"+description+"</a></html>");
             setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
@@ -86,6 +86,6 @@
 
     /**
      * Sets the URL to be visited if the user clicks on this URL label. If null, the
      * label turns into a normal label without hyperlink.
      *
      * @param url the url. Can be null.
@@ -109,8 +109,10 @@
     @Override
     public void mouseClicked(MouseEvent e) {
-        if (SwingUtilities.isLeftMouseButton(e)) {
-            OpenBrowser.displayUrl(url);
-        } else if (SwingUtilities.isRightMouseButton(e)) {
-            ClipboardUtils.copyString(url);
+        if (url != null && !url.isEmpty()) {
+            if (SwingUtilities.isLeftMouseButton(e)) {
+                OpenBrowser.displayUrl(url);
+            } else if (SwingUtilities.isRightMouseButton(e)) {
+                ClipboardUtils.copyString(url);
+            }
         }
     }
@@ -86,6 +86,6 @@
 
     /**
-     * Sets the URL to be visited if the user clicks on this URL label. If null, the
-     * label turns into a normal label without hyperlink.
+     * Sets the URL to be visited if the user clicks on this URL label.
+     * If null or empty, the label turns into a normal label without hyperlink.
      *
      * @param url the url. Can be null.
